<?php

namespace Bonus\Litecms\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Bonus\Litecms\Http\Requests\OtherIncomeRequest;
use Bonus\Litecms\Interfaces\OtherIncomeRepositoryInterface;
use Bonus\Litecms\Models\OtherIncome;

/**
 * Resource controller class for other_income.
 */
class OtherIncomeResourceController extends BaseController
{

    /**
     * Initialize other_income resource controller.
     *
     * @param type OtherIncomeRepositoryInterface $other_income
     *
     * @return null
     */
    public function __construct(OtherIncomeRepositoryInterface $other_income)
    {
        parent::__construct();
        $this->repository = $other_income;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Bonus\Litecms\Repositories\Criteria\OtherIncomeResourceCriteria::class);
    }

    /**
     * Display a list of other_income.
     *
     * @return Response
     */
    public function index(OtherIncomeRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Bonus\Litecms\Repositories\Presenter\OtherIncomePresenter::class)
                ->$function();
        }

        $other_incomes = $this->repository->paginate();

        return $this->response->title(trans('litecms::other_income.names'))
            ->view('litecms::other_income.index', true)
            ->data(compact('other_incomes'))
            ->output();
    }

    /**
     * Display other_income.
     *
     * @param Request $request
     * @param Model   $other_income
     *
     * @return Response
     */
    public function show(OtherIncomeRequest $request, OtherIncome $other_income)
    {

        if ($other_income->exists) {
            $view = 'litecms::other_income.show';
        } else {
            $view = 'litecms::other_income.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('litecms::other_income.name'))
            ->data(compact('other_income'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new other_income.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(OtherIncomeRequest $request)
    {

        $other_income = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('litecms::other_income.name')) 
            ->view('litecms::other_income.create', true) 
            ->data(compact('other_income'))
            ->output();
    }

    /**
     * Create new other_income.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(OtherIncomeRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $other_income                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('litecms::other_income.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('litecms/other_income/' . $other_income->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/litecms/other_income'))
                ->redirect();
        }

    }

    /**
     * Show other_income for editing.
     *
     * @param Request $request
     * @param Model   $other_income
     *
     * @return Response
     */
    public function edit(OtherIncomeRequest $request, OtherIncome $other_income)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('litecms::other_income.name'))
            ->view('litecms::other_income.edit', true)
            ->data(compact('other_income'))
            ->output();
    }

    /**
     * Update the other_income.
     *
     * @param Request $request
     * @param Model   $other_income
     *
     * @return Response
     */
    public function update(OtherIncomeRequest $request, OtherIncome $other_income)
    {
        try {
            $attributes = $request->all();

            $other_income->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('litecms::other_income.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('litecms/other_income/' . $other_income->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('litecms/other_income/' . $other_income->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the other_income.
     *
     * @param Model   $other_income
     *
     * @return Response
     */
    public function destroy(OtherIncomeRequest $request, OtherIncome $other_income)
    {
        try {

            $other_income->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('litecms::other_income.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('litecms/other_income/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('litecms/other_income/' . $other_income->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple other_income.
     *
     * @param Model   $other_income
     *
     * @return Response
     */
    public function delete(OtherIncomeRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('litecms::other_income.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('litecms/other_income'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/litecms/other_income'))
                ->redirect();
        }

    }

    /**
     * Restore deleted other_incomes.
     *
     * @param Model   $other_income
     *
     * @return Response
     */
    public function restore(OtherIncomeRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('litecms::other_income.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/litecms/other_income'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/litecms/other_income/'))
                ->redirect();
        }

    }

}
