<?php

namespace Bonus\Litecms\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bonus\Litecms\Models\OtherIncome;

class OtherIncomePolicy
{

    /**
     * Determine if the given user can view the other_income.
     *
     * @param UserPolicy $user
     * @param OtherIncome $other_income
     *
     * @return bool
     */
    public function view(UserPolicy $user, OtherIncome $other_income)
    {
        if ($user->canDo('litecms.other_income.view') && $user->isAdmin()) {
            return true;
        }

        return $other_income->user_id == user_id() && $other_income->user_type == user_type();
    }

    /**
     * Determine if the given user can create a other_income.
     *
     * @param UserPolicy $user
     * @param OtherIncome $other_income
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('litecms.other_income.create');
    }

    /**
     * Determine if the given user can update the given other_income.
     *
     * @param UserPolicy $user
     * @param OtherIncome $other_income
     *
     * @return bool
     */
    public function update(UserPolicy $user, OtherIncome $other_income)
    {
        if ($user->canDo('litecms.other_income.edit') && $user->isAdmin()) {
            return true;
        }

        return $other_income->user_id == user_id() && $other_income->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given other_income.
     *
     * @param UserPolicy $user
     * @param OtherIncome $other_income
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, OtherIncome $other_income)
    {
        return $other_income->user_id == user_id() && $other_income->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given other_income.
     *
     * @param UserPolicy $user
     * @param OtherIncome $other_income
     *
     * @return bool
     */
    public function verify(UserPolicy $user, OtherIncome $other_income)
    {
        if ($user->canDo('litecms.other_income.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given other_income.
     *
     * @param UserPolicy $user
     * @param OtherIncome $other_income
     *
     * @return bool
     */
    public function approve(UserPolicy $user, OtherIncome $other_income)
    {
        if ($user->canDo('litecms.other_income.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
